/*!
 * 
 *    magic-rows v1.0.3
 *    Adds rows to your forms automagically
 *    Copyright (c) 2016 Francois Chalifour
 *    https://github.com/francoischalifour/magic-rows
 *    MIT license
 * 
 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define("magic-rows", [], factory);
	else if(typeof exports === 'object')
		exports["magic-rows"] = factory();
	else
		root["magic-rows"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;
/******/
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports) {

	'use strict';
	
	function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }
	
	var magicRows = function magicRows(input) {
	  if (!input || !input.tagName || input.tagName !== 'INPUT') return;
	
	  var addEventListeners = function addEventListeners() {
	    lastRow.addEventListener('focus', addRow);
	    lastRow.addEventListener('change', addRow);
	  };
	
	  var removeEventListeners = function removeEventListeners() {
	    lastRow.removeEventListener('focus', addRow);
	    lastRow.removeEventListener('change', addRow);
	  };
	
	  var getLetter = function getLetter(number) {
	    return String.fromCharCode(96 + number).toUpperCase();
	  };
	
	  var hasNumber = function hasNumber(string) {
	    return (/\d/.test(string)
	    );
	  };
	
	  var guessNextPatternNumber = function guessNextPatternNumber() {
	    var likelyAttribute = lastRow.getAttribute('id') || lastRow.getAttribute('name') || lastRow.getAttribute('placeholder');
	
	    var numberGuessed = Number(likelyAttribute.replace(/^\D+/g, '')) + 1;
	
	    return numberGuessed;
	  };
	
	  var getNextValue = function getNextValue(value, format) {
	    if (format) {
	      return format.includes('$') ? format.replace(/\$+/g, getPatternNumbers(format, format.split('$').length - 1)) : format.includes('@') ? format.replace('@', getLetter(guessNextPatternNumber())) : guessNextValue(value);
	    } else {
	      return guessNextValue(value, true);
	    }
	  };
	
	  var getPatternNumbers = function getPatternNumbers(format, noDigits) {
	    var newValue = (Array(noDigits).fill('0').join('') + guessNextPatternNumber(format)).slice(-noDigits);
	
	    return newValue;
	  };
	
	  var guessNextValue = function guessNextValue(value, detection) {
	    var noDigits = value.toString().slice(-1) === '9' ? value.replace(/^\D+/g, '').length : value.replace(/^\D+/g, '').length + 1;
	
	    return detection ? value.replace(/\d+/g, function (n) {
	      return ++n;
	    }) : hasNumber(value) ? value.replace(/\d+/g, getPatternNumbers(value, noDigits)) : value + '-' + noRows;
	  };
	
	  var cloneRow = function cloneRow(row) {
	    var newRow = lastRow.cloneNode(true);
	    newRow.value = '';
	
	    return newRow;
	  };
	
	  var fillRow = function fillRow(row) {
	    var id = row.getAttribute('id');
	    var placeholder = row.getAttribute('placeholder');
	    var name = row.getAttribute('name');
	
	    if (id) row.setAttribute('id', getNextValue(id, idFormat));
	    if (placeholder) row.setAttribute('placeholder', getNextValue(placeholder, placeholderFormat));
	    if (name) row.setAttribute('name', getNextValue(name, nameFormat));
	
	    return row;
	  };
	
	  var insertRow = function insertRow(reference, node) {
	    reference.parentNode.insertBefore(node, reference.nextSibling);
	  };
	
	  var addRow = function addRow() {
	    if (noRows >= maxRows) return;
	    if (noRows > 1) {
	      if (!secondLastRow.value) return;
	    }
	
	    removeEventListeners();
	    noRows++;
	
	    var clonedRow = cloneRow(lastRow);
	    var newRow = fillRow(clonedRow);
	
	    insertRow(lastRow, newRow);
	
	    secondLastRow = lastRow;
	    lastRow = newRow;
	
	    addEventListeners();
	  };
	
	  var noRows = 1;
	  var secondLastRow = void 0;
	  var lastRow = input;
	
	  var maxRows = input.dataset.maxRows || 10;
	  var placeholderFormat = input.dataset.formatPlaceholder;
	  var idFormat = input.dataset.formatId;
	  var nameFormat = input.dataset.formatName;
	
	  addEventListeners();
	};
	
	window.addEventListener('load', function () {
	  [].concat(_toConsumableArray(document.querySelectorAll('[data-action="magic-rows"]'))).forEach(function (input) {
	    return magicRows(input);
	  });
	});

/***/ }
/******/ ])
});
;
//# sourceMappingURL=magic-rows.js.map