const magicRows = input => {
  if (!input || !input.tagName || input.tagName !== 'INPUT') return

  const addEventListeners = () => {
    lastRow.addEventListener('focus', addRow)
    lastRow.addEventListener('change', addRow)
  }

  const removeEventListeners = () => {
    lastRow.removeEventListener('focus', addRow)
    lastRow.removeEventListener('change', addRow)
  }

  const getLetter = (number) => {
    return String.fromCharCode(96 + number).toUpperCase()
  }

  const hasNumber = (string) => {
    return /\d/.test(string)
  }

  const guessNextPatternNumber = () => {
    const likelyAttribute =
      lastRow.getAttribute('id') ||
      lastRow.getAttribute('name') ||
      lastRow.getAttribute('placeholder')

    const numberGuessed = Number(likelyAttribute.replace(/^\D+/g, '')) + 1

    return numberGuessed
  }

  const getNextValue = (value, format) => {
    if (format) {
      return format.includes('$')
        ? format.replace(/\$+/g, getPatternNumbers(format, format.split('$').length - 1))
        : format.includes('@')
          ? format.replace('@', getLetter(guessNextPatternNumber()))
          : guessNextValue(value)
    } else {
      return guessNextValue(value, true)
    }
  }

  const getPatternNumbers = (format, noDigits) => {
    const newValue = (Array(noDigits).fill('0').join('') + guessNextPatternNumber(format)).slice(-noDigits)

    return newValue
  }

  const guessNextValue = (value, detection) => {
    const noDigits = value.toString().slice(-1) === '9'
      ? value.replace(/^\D+/g, '').length
      : value.replace(/^\D+/g, '').length + 1

    return detection
      ? value.replace(/\d+/g, n => ++n)
      : hasNumber(value)
        ? value.replace(/\d+/g, getPatternNumbers(value, noDigits))
        : `${value}-${noRows}`
  }

  const cloneRow = row => {
    const newRow = lastRow.cloneNode(true)
    newRow.value = ''

    return newRow
  }

  const fillRow = row => {
    const id = row.getAttribute('id')
    const placeholder = row.getAttribute('placeholder')
    const name = row.getAttribute('name')

    if (id) row.setAttribute('id', getNextValue(id, idFormat))
    if (placeholder) row.setAttribute('placeholder', getNextValue(placeholder, placeholderFormat))
    if (name) row.setAttribute('name', getNextValue(name, nameFormat))

    return row
  }

  const insertRow = (reference, node) => {
    reference.parentNode.insertBefore(node, reference.nextSibling)
  }

  const addRow = () => {
    if (noRows >= maxRows) return
    if (noRows > 1) {
      if (!secondLastRow.value) return
    }

    removeEventListeners()
    noRows++

    const clonedRow = cloneRow(lastRow)
    const newRow = fillRow(clonedRow)

    insertRow(lastRow, newRow)

    secondLastRow = lastRow
    lastRow = newRow

    addEventListeners()
  }

  let noRows = 1
  let secondLastRow
  let lastRow = input

  const maxRows = input.dataset.maxRows || 10
  const placeholderFormat = input.dataset.formatPlaceholder
  const idFormat = input.dataset.formatId
  const nameFormat = input.dataset.formatName

  addEventListeners()
}

window.addEventListener('load', () => {
  [...document.querySelectorAll('[data-action="magic-rows"]')]
    .forEach(input => magicRows(input))
})
